searchData={"items":[{"type":"module","title":"Gettext","doc":"The `Gettext` module provides a\n[gettext](https://www.gnu.org/software/gettext/)-based API for working with\ninternationalized applications.","ref":"Gettext.html"},{"type":"module","title":"Basic Overview - Gettext","doc":"When you use Gettext, you replace hardcoded user-facing text like this:\n\n    \"Hello world\"\n\nwith calls like this:\n\n    gettext(\"Hello world\")\n\nHere, the string `\"Hello world\"` serves two purposes:\n\n  1. It's displayed by default (if no translation is specified in the current\n     language). This means that, at the very least, switching from a hardcoded\n     string to a Gettext call is harmless.\n\n  2. It serves as the message ID to which translations will be mapped.\n\nAn example translation workflow is as follows.\n\nFirst, call `mix gettext.extract` to extract `gettext()` calls to `.pot`\n([Portable Object Template](https://www.gnu.org/software/gettext/manual/html_node/PO-Files.html))\nfiles, which are the base for all translations. These files are *templates*, which\nmeans they only contain message IDs, and not actual translated strings. POT files have\nentries like this:\n\n    #: lib/myapp_web/live/hello_live.html.heex:2\n    #, elixir-autogen, elixir-format\n    msgid \"Hello world\"\n    msgstr \"\"\n\nThen, call `mix gettext.merge priv/gettext` to update all\nlocale-specific `.po` (Portable Object) files so that they include this message ID.\nEntries in PO files contain translations for their specific locale. For example,\nin a PO file for Italian, the entry above would look like this:\n\n    #: lib/myapp_web/live/hello_live.html.heex:2\n    #, elixir-autogen, elixir-format\n    msgid \"Hello world\"\n    msgstr \"Ciao mondo\"\n\nThe English string is the `msgid` which is used to look up the\ncorrect Italian string.\nThat's handy, because unlike a generic key like `site.greeting` (as some\ntranslations systems use), the message ID tells exactly what needs to be\ntranslated. This is easier to work with for translators, for example.\n\nBut it raises a question: what if you change the original English string in the code?\nDoes that break all translations, requiring manual edits everywhere? Not necessarily.\nAfter you run `mix gettext.extract` again, the next `mix gettext.merge` can\ndo **fuzzy matching**.\nSo, if you change `\"Hello world\"` to `\"Hello world!\"`, Gettext will see that the new\nmessage ID is similar to an existing `msgid`, and will do two things:\n\n  1. It will update the `msgid` in all `.po` files to match the new text.\n\n  2. It will mark those entries as \"fuzzy\"; this hints that a (probably human)\n     translator should check whether the Italian translation of this string needs\n     an update.\n\nThe resulting change in the `.po` file is this (note the \"fuzzy\" annotation):\n\n    #: lib/myapp_web/live/hello_live.html.heex:2\n    #, elixir-autogen, elixir-format, fuzzy\n    msgid \"Hello world!\"\n    msgstr \"Ciao mondo\"\n\nThis \"fuzzy matching\" behavior can be configured or disabled, but its\nexistence makes updating translations to match changes in the base text easier.\n\nThe rest of the documentation will cover the Gettext API in detail.","ref":"Gettext.html#module-basic-overview"},{"type":"module","title":"Gettext API - Gettext","doc":"To use `Gettext`, a module that calls `use Gettext` (referred to below as a\n\"backend\") has to be defined:\n\n    defmodule MyApp.Gettext do\n      use Gettext, otp_app: :my_app\n    end\n\nThis automatically defines some macros in the `MyApp.Gettext` backend module.\nHere are some examples:\n\n    import MyApp.Gettext\n\n    # Simple message\n    gettext(\"Here is the string to translate\")\n\n    # Plural message\n    ngettext(\n      \"Here is the string to translate\",\n      \"Here are the strings to translate\",\n      3\n    )\n\n    # Domain-based message\n    dgettext(\"errors\", \"Here is the error message to translate\")\n\n    # Context-based message\n    pgettext(\"email\", \"Email text to translate\")\n\n    # All of the above\n    dpngettext(\n      \"errors\",\n      \"context\",\n      \"Here is the string to translate\",\n      \"Here are the strings to translate\",\n      3\n    )\n\nThe arguments for the Gettext macros and their order can be derived from\ntheir names. For `dpgettext/4` the arguments are: `domain`, `context`,\n`msgid`, `bindings` (default to `%{}`).\n\nMessages are looked up from `.po` files. In the following sections we will\nexplore exactly what are those files before we explore the \"Gettext API\" in\ndetail.","ref":"Gettext.html#module-gettext-api"},{"type":"module","title":"Messages - Gettext","doc":"Messages are stored inside PO (Portable Object) files, with a `.po`\nextension. For example, this is a snippet from a PO file:\n\n    # This is a comment\n    msgid \"Hello world!\"\n    msgstr \"Ciao mondo!\"\n\nPO files containing messages for an application must be stored in a\ndirectory (by default it's `priv/gettext`) that has the following structure:\n\n    gettext directory\n    └─ locale\n       └─ LC_MESSAGES\n          ├─ domain_1.po\n          ├─ domain_2.po\n          └─ domain_3.po\n\nHere, `locale` is the locale of the messages (for example, `en_US`),\n`LC_MESSAGES` is a fixed directory, and `domain_i.po` are PO files containing\ndomain-scoped messages. For more information on domains, check out the\n\"Domains\" section below.\n\nA concrete example of such a directory structure could look like this:\n\n    priv/gettext\n    └─ en_US\n    |  └─ LC_MESSAGES\n    |     ├─ default.po\n    |     └─ errors.po\n    └─ it\n       └─ LC_MESSAGES\n          ├─ default.po\n          └─ errors.po\n\nBy default, Gettext expects messages to be stored under the `priv/gettext`\ndirectory of an application. This behaviour can be changed by specifying a\n`:priv` option when using `Gettext`:\n\n    # Look for messages in my_app/priv/messages instead of\n    # my_app/priv/gettext\n    use Gettext, otp_app: :my_app, priv: \"priv/messages\"\n\nThe messages directory specified by the `:priv` option should be a directory\ninside `priv/`, otherwise some things won't work as expected.","ref":"Gettext.html#module-messages"},{"type":"module","title":"Locale - Gettext","doc":"At runtime, all gettext-related functions and macros that do not explicitly\ntake a locale as an argument read the locale from the backend and fall back\nto Gettext's default locale.\n\n`Gettext.put_locale/1` can be used to change the locale of all backends for\nthe current Elixir process. That's the preferred mechanism for setting the\nlocale at runtime. `Gettext.put_locale/2` can be used when you want to set the\nlocale of one specific Gettext backend without affecting other Gettext\nbackends.\n\nSimilarly, `Gettext.get_locale/0` gets the locale for all backends in the\ncurrent process. `Gettext.get_locale/1` gets the locale of a specific backend\nfor the current process. Check their documentation for more information.\n\nLocales are expressed as strings (like `\"en\"` or `\"fr\"`); they can be\narbitrary strings as long as they match a directory name. As mentioned above,\nthe locale is stored **per-process** (in the process dictionary): this means\nthat the locale must be set in every new process in order to have the right\nlocale available for that process. Pay attention to this behaviour, since not\nsetting the locale *will not* result in any errors when `Gettext.get_locale/0`\nor `Gettext.get_locale/1` are called; the default locale will be\nreturned instead.\n\nTo decide which locale to use, each gettext-related function in a given\nbackend follows these steps:\n\n  * if there is a backend-specific locale for the given backend for this\n    process (see `put_locale/2`), use that, otherwise\n  * if there is a global locale for this process (see `put_locale/1`), use\n    that, otherwise\n  * if there is a backend-specific default locale in the configuration for\n    that backend's `:otp_app` (see the \"Default locale\" section below), use\n    that, otherwise\n  * use the default global Gettext locale (see the \"Default locale\" section\n    below)","ref":"Gettext.html#module-locale"},{"type":"module","title":"Default locale - Gettext","doc":"The global Gettext default locale can be configured through the\n`:default_locale` key of the `:gettext` application:\n\n    config :gettext, :default_locale, \"fr\"\n\nBy default the global locale is `\"en\"`. See also `get_locale/0` and\n`put_locale/1`.\n\nIf for some reason a backend requires a different `:default_locale`\nthan all other backends, you can set the `:default_locale` inside the\nbackend configuration, but this approach is generally discouraged as\nit makes it hard to track which locale each backend is using:\n\n    config :my_app, MyApp.Gettext, default_locale: \"fr\"","ref":"Gettext.html#module-default-locale"},{"type":"module","title":"Gettext API - Gettext","doc":"There are two ways to use Gettext:\n\n  * using macros from your own Gettext module, like `MyApp.Gettext`\n  * using functions from the `Gettext` module\n\nThese two approaches are different and each one has its own use case.","ref":"Gettext.html#module-gettext-api"},{"type":"module","title":"Using macros - Gettext","doc":"Each module that calls `use Gettext` is usually referred to as a \"Gettext\nbackend\", as it implements the `Gettext.Backend` behaviour. When a module\ncalls `use Gettext`, the following macros are automatically\ndefined inside it:\n\n  * `gettext/2`\n  * `dgettext/3`\n  * `pgettext/3`\n  * `dpgettext/4`\n  * `ngettext/4`\n  * `dngettext/6`\n  * `pngettext/6`\n  * `dpngettext/6`\n  * all macros above with a `_noop` suffix (and without accepting bindings), for\n    example `pgettext_noop/2`\n\nSupposing the caller module is `MyApp.Gettext`, the macros mentioned above\nbehave as follows:\n\n  * `gettext(msgid, bindings \\\\ %{})` -\n    like `Gettext.gettext(MyApp.Gettext, msgid, bindings)`\n\n  * `dgettext(domain, msgid, bindings \\\\ %{})` -\n    like `Gettext.dgettext(MyApp.Gettext, domain, msgid, bindings)`\n\n  * `pgettext(msgctxt, msgid, bindings \\\\ %{})` -\n    like `Gettext.pgettext(MyApp.Gettext, msgctxt, msgid, bindings)`\n\n  * `dpgettext(domain, msgctxt, msgid, bindings \\\\ %{})` -\n    like `Gettext.dpgettext(MyApp.Gettext, domain, msgctxt, msgid, bindings)`\n\n  * `ngettext(msgid, msgid_plural, n, bindings \\\\ %{})` -\n    like `Gettext.ngettext(MyApp.Gettext, msgid, msgid_plural, n, bindings)`\n\n  * `dngettext(domain, msgid, msgid_plural, n, bindings \\\\ %{})` -\n    like `Gettext.dngettext(MyApp.Gettext, domain, msgid, msgid_plural, n, bindings)`\n\n  * `pngettext(msgctxt, msgid, msgid_plural, n, bindings \\\\ %{})` -\n    like `Gettext.pngettext(MyApp.Gettext, msgctxt, msgid, msgid_plural, n, bindings)`\n\n  * `dpngettext(domain, msgctxt, msgid, msgid_plural, n, bindings \\\\ %{})` -\n    like `Gettext.dpngettext(MyApp.Gettext, domain, msgctxt, msgid, msgid_plural, n, bindings)`\n\n  * `*_noop` family of functions - used to mark messages for extraction\n    without translating them. See the documentation for these macros in\n    `Gettext.Backend`\n\nSee also the `Gettext.Backend` behaviour for more detailed documentation about\nthese macros.\n\nUsing macros is preferred as Gettext is able to automatically sync the\nmessages in your code with PO files. This, however, imposes a constraint:\narguments passed to any of these macros have to be strings **at compile\ntime**. This means that they have to be string literals or something that\nexpands to a string literal at compile time (for example, a module attribute like\n`@my_string \"foo\"`).\n\nThese are all valid uses of the Gettext macros:\n\n    Gettext.put_locale(MyApp.Gettext, \"it\")\n\n    MyApp.Gettext.gettext(\"Hello world\")\n    #=> \"Ciao mondo\"\n\n    @msgid \"Hello world\"\n    MyApp.Gettext.gettext(@msgid)\n    #=> \"Ciao mondo\"\n\nThe `*gettext` macros raise an `ArgumentError` exception if they receive a\n`domain`, `msgctxt`, `msgid`, or `msgid_plural` that doesn't expand to a string\n*at compile time*:\n\n    msgid = \"Hello world\"\n    MyApp.Gettext.gettext(msgid)\n    #=> ** (ArgumentError) msgid must be a string literal\n\nUsing compile-time strings isn't always possible. For this reason,\nthe `Gettext` module provides a set of functions as well.","ref":"Gettext.html#module-using-macros"},{"type":"module","title":"Using functions - Gettext","doc":"If compile-time strings cannot be used, the solution is to use the functions\nin the `Gettext` module instead of the macros described above. These functions\nperfectly mirror the macro API, but they all expect a module name as the first\nargument. This module has to be a module which calls `use Gettext`. For example:\n\n    defmodule MyApp.Gettext do\n      use Gettext, otp_app: :my_app\n    end\n\n    Gettext.put_locale(MyApp.Gettext, \"pt_BR\")\n\n    msgid = \"Hello world\"\n    Gettext.gettext(MyApp.Gettext, msgid)\n    #=> \"Olá mundo\"\n\nWhile using functions from the `Gettext` module yields the same results as\nusing macros (with the added benefit of dynamic arguments), all the\ncompile-time features mentioned in the previous section are lost.","ref":"Gettext.html#module-using-functions"},{"type":"module","title":"Domains - Gettext","doc":"The `dgettext` and `dngettext` functions/macros also accept a *domain* as one\nof the arguments. The domain of a message is determined by the name of the\nPO file that contains that message. For example, the domain of\nmessages in the `it/LC_MESSAGES/errors.po` file is `\"errors\"`, so those\nmessages would need to be retrieved with `dgettext` or `dngettext`:\n\n    MyApp.Gettext.dgettext(\"errors\", \"Error!\")\n    #=> \"Errore!\"\n\nWhen backend `gettext`, `ngettext`, or `pgettext` are used, the backend's\ndefault domain is used (which defaults to \"default\"). The `Gettext`\nfunctions accepting a backend (`gettext/3`, `ngettext/5`, and `pgettext/4`)\n_always_ use a domain of \"default\".","ref":"Gettext.html#module-domains"},{"type":"module","title":"Default Domain - Gettext","doc":"Each backend can be configured with a specific `:default_domain`\nthat replaces `\"default\"` in `gettext/2`, `pgettext/3`, and `ngettext/4`\nfor that backend.\n\n    defmodule MyApp.Gettext do\n      use Gettext, otp_app: :my_app, default_domain: \"messages\"\n    end\n\n    config :my_app, MyApp.Gettext, default_domain: \"messages\"","ref":"Gettext.html#module-default-domain"},{"type":"module","title":"Contexts - Gettext","doc":"The GNU Gettext implementation supports\n[*contexts*](https://www.gnu.org/software/gettext/manual/html_node/Contexts.html),\nwhich are a way to contextualize messages. For example, in English, the\nword \"file\" could be used both as a noun as well as a verb. Contexts can be used to\nsolve similar problems: you could have a `imperative_verbs` context and a\n`nouns` context as to avoid ambiguity. The functions that handle contexts\nhave a `p` in their name (to match the GNU Gettext API), and are `pgettext`,\n`dpgettext`, `pngettext`, and `dpngettext`. The \"p\" stands for \"particular\".","ref":"Gettext.html#module-contexts"},{"type":"module","title":"Interpolation - Gettext","doc":"All `*gettext` functions and macros provided by Gettext support interpolation.\nInterpolation keys can be placed in `msgid`s or `msgid_plural`s with by\nenclosing them in `%{` and `}`, like this:\n\n    \"This is an %{interpolated} string\"\n\nInterpolation bindings can be passed as an argument to all of the `*gettext`\nfunctions/macros. For example, given the following PO file for the `\"it\"`\nlocale:\n\n    msgid \"Hello, %{name}!\"\n    msgstr \"Ciao, %{name}!\"\n\ninterpolation can be done like follows:\n\n    Gettext.put_locale(MyApp.Gettext, \"it\")\n    MyApp.Gettext.gettext(\"Hello, %{name}!\", name: \"Meg\")\n    #=> \"Ciao, Meg!\"\n\nInterpolation keys that are in a string but not in the provided bindings\nresult in an exception:\n\n    MyApp.Gettext.gettext(\"Hello, %{name}!\")\n    #=> ** (Gettext.MissingBindingsError) ...\n\nKeys that are in the interpolation bindings but that don't occur in the string\nare ignored. Interpolations in Gettext are often expanded at compile time,\nensuring a low performance cost when running them at runtime.","ref":"Gettext.html#module-interpolation"},{"type":"module","title":"Pluralization - Gettext","doc":"Pluralization in Gettext for Elixir works very similar to how pluralization\nworks in GNU Gettext. The `*ngettext` functions/macros accept a `msgid`, a\n`msgid_plural` and a count of elements; the right message is chosen based\non the **pluralization rule** for the given locale.\n\nFor example, given the following snippet of PO file for the `\"it\"` locale:\n\n    msgid \"One error\"\n    msgid_plural \"%{count} errors\"\n    msgstr[0] \"Un errore\"\n    msgstr[1] \"%{count} errori\"\n\nthe `ngettext` macro can be used like this:\n\n    Gettext.put_locale(MyApp.Gettext, \"it\")\n    MyApp.Gettext.ngettext(\"One error\", \"%{count} errors\", 3)\n    #=> \"3 errori\"\n\nThe `%{count}` interpolation key is a special key since it gets replaced by\nthe number of elements argument passed to `*ngettext`, like if the `count: 3`\nkey-value pair were in the interpolation bindings. Hence, never pass the\n`count` key in the bindings:\n\n    # `count: 4` is ignored here\n    MyApp.Gettext.ngettext(\"One error\", \"%{count} errors\", 3, count: 4)\n    #=> \"3 errori\"\n\nYou can specify a \"pluralizer\" module via the `:plural_forms` option in the\nconfiguration for each Gettext backend.\n\n    defmodule MyApp.Gettext do\n      use Gettext, otp_app: :my_app, plural_forms: MyApp.PluralForms\n    end\n\nTo learn more about pluralization rules, plural forms and what they mean to\nGettext check the documentation for `Gettext.Plural`.","ref":"Gettext.html#module-pluralization"},{"type":"module","title":"Missing messages - Gettext","doc":"When a message is missing in the specified locale (both with functions as\nwell as with macros), the argument is returned:\n\n  * in case of calls to `gettext`/`dgettext`/`pgettext`/`dpgettext`, the `msgid` argument is returned\n    as is;\n  * in case of calls to `ngettext`/`dngettext`/`pngettext`/`dpngettext`, the `msgid` argument is\n    returned in case of a singular value and the `msgid_plural` is returned in\n    case of a plural value (following the English pluralization rule).\n\nFor example:\n\n    Gettext.put_locale(MyApp.Gettext, \"foo\")\n    MyApp.Gettext.gettext(\"Hey there\")\n    #=> \"Hey there\"\n    MyApp.Gettext.ngettext(\"One error\", \"%{count} errors\", 3)\n    #=> \"3 errors\"","ref":"Gettext.html#module-missing-messages"},{"type":"module","title":"Empty messages - Gettext","doc":"When a `msgstr` is empty (`\"\"`), the message is considered missing and the\nbehaviour described above for missing message is applied. A plural\nmessage is considered to have an empty `msgstr` if at least one\nmessage in the `msgstr` is empty.","ref":"Gettext.html#module-empty-messages"},{"type":"module","title":"Compile-time features - Gettext","doc":"As mentioned above, using the Gettext macros (as opposed to functions) allows\nGettext to operate on those messages *at compile-time*. This can be used\nto extract messages from the source code into POT (Portable Object Template)\nfiles automatically (instead of having to manually add messages to POT files\nwhen they're added to the source code). The `gettext.extract` does exactly\nthis: whenever there are new messages in the source code, running\n`gettext.extract` syncs the existing POT files with the changed code base.\nRead the documentation for `Mix.Tasks.Gettext.Extract` for more information\non the extraction process.\n\nPOT files are just *template* files and the messages in them do not\nactually contain translated strings. A POT file looks like this:\n\n    # The msgstr is empty\n    msgid \"hello, world\"\n    msgstr \"\"\n\nWhenever a POT file changes, it's likely that developers (or translators) will\nwant to update the corresponding PO files for each locale. To do that, gettext\nprovides the `gettext.merge` Mix task. For example, running:\n\n    mix gettext.merge priv/gettext --locale pt_BR\n\nwill update all the PO files in `priv/gettext/pt_BR/LC_MESSAGES` with the new\nversion of the POT files in `priv/gettext`. Read more about the merging\nprocess in the documentation for `Mix.Tasks.Gettext.Merge`.","ref":"Gettext.html#module-compile-time-features"},{"type":"module","title":"Configuration - Gettext","doc":"### `:gettext` configuration\n\nThe `:gettext` application supports the following configuration options:\n\n  * `:default_locale` - a string which specifies the default global Gettext\n    locale to use for all backends. See the \"Locale\" section for more\n    information on backend-specific, global, and default locales.","ref":"Gettext.html#module-configuration"},{"type":"module","title":"Backend configuration - Gettext","doc":"A **Gettext backend** supports some options to be configured. These options\ncan be configured in two ways: either by passing them to `use Gettext` (hence\nat compile time):\n\n    defmodule MyApp.Gettext do\n      use Gettext, options\n    end\n\nor by using Mix configuration, configuring the key corresponding to the\nbackend in the configuration for your application:\n\n    # For example, in config/config.exs\n    config :my_app, MyApp.Gettext, options\n\nNote that the `:otp_app` option (an atom representing an OTP application) has\nto always be present and has to be passed to `use Gettext` because it's used\nto determine the application to read the configuration of (`:my_app` in the\nexample above); for this reason, `:otp_app` can't be configured via the Mix\nconfiguration. This option is also used to determine the application's\ndirectory where to search messages in.\n\nThe following is a comprehensive list of supported options:\n\n  * `:priv` - a string representing a directory where messages will be\n    searched. The directory is relative to the directory of the application\n    specified by the `:otp_app` option. It is recommended to always have\n    this directory inside `\"priv\"`, otherwise some features won't work as expected.\n    By default it's `\"priv/gettext\"`.\n\n  * `:plural_forms` - a module which will act as a \"pluralizer\". For more\n    information, look at the documentation for `Gettext.Plural`.\n\n  * `:default_locale` - a string which specifies the default locale to use for\n    the given backend.\n\n  * `:split_module_by` - instead of bundling all locales into a single\n    module, this option makes Gettext build internal modules per locale,\n    per domain, or both. This reduces compilation times and beam file sizes\n    for large projects. For example: `split_module_by: [:locale, :domain]`.\n\n  * `:split_module_compilation` - control if compilation of split modules\n    should happen in `:parallel` (the default) or `:serial`.\n\n  * `:allowed_locales` - a list of locales to bundle in the backend.\n    Defaults to all the locales discovered in the `:priv` directory.\n    This option can be useful in development to reduce compile-time\n    by compiling only a subset of all available locales.\n\n  * `:interpolation` - the name of a module that implements the\n    `Gettext.Interpolation` behaviour. Default: `Gettext.Interpolation.Default`","ref":"Gettext.html#module-backend-configuration"},{"type":"module","title":"Mix tasks configuration - Gettext","doc":"You can configure Gettext Mix tasks under the `:gettext` key in the\nconfiguration returned by `project/0` in `mix.exs`:\n\n    def project() do\n      [app: :my_app,\n       # ...\n       gettext: [...]]\n    end\n\nThe following is a list of the supported configuration options:\n\n  * `:fuzzy_threshold` - the default threshold for the Jaro distance measuring\n    the similarity of messages. Look at the documentation for the `mix\n    gettext.merge` task (`Mix.Tasks.Gettext.Merge`) for more information on\n    fuzzy messages.\n\n  * `:excluded_refs_from_purging` - a regex that is matched against message\n    references. Gettext will preserve all messages in all POT files that\n    have a matching reference. You can use this pattern to prevent Gettext from\n    removing messages that you have extracted using another tool.\n\n  * `:custom_flags_to_keep` - a list of custom flags that will be kept for\n    existing messages during a merge. Gettext always keeps the `fuzzy` flag.\n    If you want to keep the `elixir-format` flag, which is also commonly\n    used by Gettext, add it to this list. Available since v0.23.0.\n\n  * `:write_reference_comments` - a boolean that specifies whether reference\n    comments should be written when outputting PO(T) files. If this is `false`,\n    reference comments will not be written when extracting messages or merging\n    messages, and the ones already found in files will be discarded.\n\n  * `:write_reference_line_numbers` - a boolean that specifies whether file\n    reference comments include line numbers when outputting PO(T) files.\n    Defaults to `true`.\n\n  * `:sort_by_msgid` - modifies the sorting behavior. Can be either `nil` (the default),\n    `:case_sensitive`, or `:case_insensitive`.\n    By default or if `nil`, the order of existing messages in a POT file is kept and new\n    messages are appended to the file. If `:sort_by_msgid` is set to `:case_sensitive`,\n    existing and new messages will be mixed and sorted alphabetically by msgid.\n    If set to `:case_insensitive`, the same applies but the sorting is case insensitive.\n    *Note*: this option also supports `true` and `false` for backwards compatibility,\n    but these values are deprecated as of v0.21.0.\n\n  * `:on_obsolete` - controls what happens when obsolete messages are found.\n    If `:mark_as_obsolete`, messages are kept and marked as obsolete.\n    If `:delete`, obsolete messages are deleted. Defaults to `:delete`.\n\n  * `:store_previous_message_on_fuzzy_match` - a boolean that controls\n    whether to store the previous message text in case of a fuzzy match.\n    Defaults to `false`.","ref":"Gettext.html#module-mix-tasks-configuration"},{"type":"function","title":"Gettext.dgettext/4","doc":"Returns the message of the given string in the given domain.\n\nThe string is translated by the `backend` module.\n\nThe translated string is interpolated based on the `bindings` argument. For\nmore information on how interpolation works, refer to the documentation of the\n`Gettext` module.\n\nIf the message for the given `msgid` is not found, the `msgid`\n(interpolated if necessary) is returned.","ref":"Gettext.html#dgettext/4"},{"type":"function","title":"Examples - Gettext.dgettext/4","doc":"defmodule MyApp.Gettext do\n      use Gettext, otp_app: :my_app\n    end\n\n    Gettext.put_locale(MyApp.Gettext, \"it\")\n\n    Gettext.dgettext(MyApp.Gettext, \"errors\", \"Invalid\")\n    #=> \"Non valido\"\n\n    Gettext.dgettext(MyApp.Gettext, \"errors\", \"%{name} is not a valid name\", name: \"Meg\")\n    #=> \"Meg non è un nome valido\"\n\n    Gettext.dgettext(MyApp.Gettext, \"alerts\", \"nonexisting\")\n    #=> \"nonexisting\"","ref":"Gettext.html#dgettext/4-examples"},{"type":"function","title":"Gettext.dngettext/6","doc":"Returns the pluralized message of the given string in the given domain.\n\nThe string is translated and pluralized by the `backend` module.\n\nThe translated string is interpolated based on the `bindings` argument. For\nmore information on how interpolation works, refer to the documentation of the\n`Gettext` module.\n\nIf the message for the given `msgid` and `msgid_plural` is not found, the\n`msgid` or `msgid_plural` (based on `n` being singular or plural) is returned\n(interpolated if necessary).","ref":"Gettext.html#dngettext/6"},{"type":"function","title":"Examples - Gettext.dngettext/6","doc":"defmodule MyApp.Gettext do\n      use Gettext, otp_app: :my_app\n    end\n\n    Gettext.dngettext(MyApp.Gettext, \"errors\", \"Error\", \"%{count} errors\", 3)\n    #=> \"3 errori\"\n    Gettext.dngettext(MyApp.Gettext, \"errors\", \"Error\", \"%{count} errors\", 1)\n    #=> \"Errore\"","ref":"Gettext.html#dngettext/6-examples"},{"type":"function","title":"Gettext.dpgettext/5","doc":"Returns the message of the given string with a given context in the given domain.\n\nThe string is translated by the `backend` module.\n\nThe translated string is interpolated based on the `bindings` argument. For\nmore information on how interpolation works, refer to the documentation of the\n`Gettext` module.\n\nIf the message for the given `msgid` is not found, the `msgid`\n(interpolated if necessary) is returned.","ref":"Gettext.html#dpgettext/5"},{"type":"function","title":"Examples - Gettext.dpgettext/5","doc":"defmodule MyApp.Gettext do\n      use Gettext, otp_app: :my_app\n    end\n\n    Gettext.put_locale(MyApp.Gettext, \"it\")\n\n    Gettext.dpgettext(MyApp.Gettext, \"errors\", \"user error\", \"Invalid\")\n    #=> \"Non valido\"\n\n    Gettext.dgettext(MyApp.Gettext, \"errors\", \"signup form\", \"%{name} is not a valid name\", name: \"Meg\")\n    #=> \"Meg non è un nome valido\"","ref":"Gettext.html#dpgettext/5-examples"},{"type":"function","title":"Gettext.dpngettext/7","doc":"Returns the pluralized message of the given string with a given context in the given domain.\n\nThe string is translated and pluralized by the `backend` module.\n\nThe translated string is interpolated based on the `bindings` argument. For\nmore information on how interpolation works, refer to the documentation of the\n`Gettext` module.\n\nIf the message for the given `msgid` and `msgid_plural` is not found, the\n`msgid` or `msgid_plural` (based on `n` being singular or plural) is returned\n(interpolated if necessary).","ref":"Gettext.html#dpngettext/7"},{"type":"function","title":"Examples - Gettext.dpngettext/7","doc":"defmodule MyApp.Gettext do\n      use Gettext, otp_app: :my_app\n    end\n\n    Gettext.dpngettext(MyApp.Gettext, \"errors\", \"user error\", \"Error\", \"%{count} errors\", 3)\n    #=> \"3 errori\"\n    Gettext.dpngettext(MyApp.Gettext, \"errors\", \"user error\", \"Error\", \"%{count} errors\", 1)\n    #=> \"Errore\"","ref":"Gettext.html#dpngettext/7-examples"},{"type":"function","title":"Gettext.get_locale/0","doc":"Gets the global Gettext locale for the current process.\n\nThis function returns the value of the global Gettext locale for the current\nprocess. This global locale is shared between all Gettext backends; if you\nwant backend-specific locales, see `get_locale/1` and `put_locale/2`. If the\nglobal Gettext locale is not set, this function returns the default global\nlocale (configurable in the configuration for the `:gettext` application, see\nthe module documentation for more information).","ref":"Gettext.html#get_locale/0"},{"type":"function","title":"Examples - Gettext.get_locale/0","doc":"Gettext.get_locale()\n    #=> \"en\"","ref":"Gettext.html#get_locale/0-examples"},{"type":"function","title":"Gettext.get_locale/1","doc":"Gets the locale for the current process and the given backend.\n\nThis function returns the value of the locale for the current process and the\ngiven `backend`. If there is no locale for the current process and the given\nbackend, then either the global Gettext locale (if set), or the default locale\nfor the given backend, or the global default locale is returned. See the\n\"Locale\" section in the module documentation for more information.","ref":"Gettext.html#get_locale/1"},{"type":"function","title":"Examples - Gettext.get_locale/1","doc":"Gettext.get_locale(MyApp.Gettext)\n    #=> \"en\"","ref":"Gettext.html#get_locale/1-examples"},{"type":"function","title":"Gettext.gettext/3","doc":"Returns the message of the given string in the `\"default\"` domain.\n\nWorks exactly like:\n\n    Gettext.dgettext(backend, \"default\", msgid, bindings)","ref":"Gettext.html#gettext/3"},{"type":"function","title":"Gettext.known_locales/1","doc":"Returns all the locales for which PO files exist for the given `backend`.\n\nIf the messages directory for the given backend doesn't exist, then an\nempty list is returned.","ref":"Gettext.html#known_locales/1"},{"type":"function","title":"Examples - Gettext.known_locales/1","doc":"With the following backend:\n\n    defmodule MyApp.Gettext do\n      use Gettext, otp_app: :my_app\n    end\n\nand the following messages directory:\n\n    my_app/priv/gettext\n    ├─ en\n    ├─ it\n    └─ pt_BR\n\nthen:\n\n    Gettext.known_locales(MyApp.Gettext)\n    #=> [\"en\", \"it\", \"pt_BR\"]","ref":"Gettext.html#known_locales/1-examples"},{"type":"function","title":"Gettext.ngettext/5","doc":"Returns the pluralized message of the given string in the `\"default\"`\ndomain.\n\nWorks exactly like:\n\n    Gettext.dngettext(backend, \"default\", msgid, msgid_plural, n, bindings)","ref":"Gettext.html#ngettext/5"},{"type":"function","title":"Gettext.pgettext/4","doc":"Returns the message of the given string with the given context\n\nThe string is translated by the `backend` module.\n\nThe translated string is interpolated based on the `bindings` argument. For\nmore information on how interpolation works, refer to the documentation of the\n`Gettext` module.\n\nIf the message for the given `msgid` is not found, the `msgid`\n(interpolated if necessary) is returned.","ref":"Gettext.html#pgettext/4"},{"type":"function","title":"Examples - Gettext.pgettext/4","doc":"defmodule MyApp.Gettext do\n      use Gettext, otp_app: :my_app\n    end\n\n    Gettext.put_locale(MyApp.Gettext, \"it\")\n\n    Gettext.pgettext(MyApp.Gettext, \"user-interface\", \"Invalid\")\n    #=> \"Non valido\"\n\n    Gettext.pgettext(MyApp.Gettext, \"user-interface\", \"%{name} is not a valid name\", name: \"Meg\")\n    #=> \"Meg non è un nome valido\"\n\n    Gettext.pgettext(MyApp.Gettext, \"alerts-users\", \"nonexisting\")\n    #=> \"nonexisting\"","ref":"Gettext.html#pgettext/4-examples"},{"type":"function","title":"Gettext.pngettext/6","doc":"Returns the pluralized message of the given string with a given context\nin the `\"default\"` domain.\n\nWorks exactly like:\n\n    Gettext.dpngettext(backend, \"default\", context, msgid, msgid_plural, n, bindings)","ref":"Gettext.html#pngettext/6"},{"type":"function","title":"Gettext.put_locale/1","doc":"Sets the global Gettext locale for the current process.\n\nThe locale is stored in the process dictionary. `locale` must be a string; if\nit's not, an `ArgumentError` exception is raised.\n\nThe return value is the previous value of the current\nprocess's locale.","ref":"Gettext.html#put_locale/1"},{"type":"function","title":"Examples - Gettext.put_locale/1","doc":"Gettext.put_locale(\"pt_BR\")\n    #=> nil\n    Gettext.get_locale()\n    #=> \"pt_BR\"","ref":"Gettext.html#put_locale/1-examples"},{"type":"function","title":"Gettext.put_locale/2","doc":"Sets the locale for the current process and the given `backend`.\n\nThe locale is stored in the process dictionary. `locale` must be a string; if\nit's not, an `ArgumentError` exception is raised.\n\nThe return value is the previous value of the current\nprocess's locale.","ref":"Gettext.html#put_locale/2"},{"type":"function","title":"Examples - Gettext.put_locale/2","doc":"Gettext.put_locale(MyApp.Gettext, \"pt_BR\")\n    #=> nil\n    Gettext.get_locale(MyApp.Gettext)\n    #=> \"pt_BR\"","ref":"Gettext.html#put_locale/2-examples"},{"type":"function","title":"Gettext.with_locale/2","doc":"Runs `fun` with the global Gettext locale set to `locale`.\n\nThis function just sets the global Gettext locale to `locale` before running\n`fun` and sets it back to its previous value afterwards. Note that\n`put_locale/2` is used to set the locale, which is thus set only for the\ncurrent process (keep this in mind if you plan on spawning processes inside\n`fun`).\n\nThe value returned by this function is the return value of `fun`.","ref":"Gettext.html#with_locale/2"},{"type":"function","title":"Examples - Gettext.with_locale/2","doc":"Gettext.put_locale(\"fr\")\n\n    MyApp.Gettext.gettext(\"Hello world\")\n    #=> \"Bonjour monde\"\n\n    Gettext.with_locale(\"it\", fn ->\n      MyApp.Gettext.gettext(\"Hello world\")\n    end)\n    #=> \"Ciao mondo\"\n\n    MyApp.Gettext.gettext(\"Hello world\")\n    #=> \"Bonjour monde\"","ref":"Gettext.html#with_locale/2-examples"},{"type":"function","title":"Gettext.with_locale/3","doc":"Runs `fun` with the Gettext locale set to `locale` for the given `backend`.\n\nThis function just sets the Gettext locale for `backend` to `locale` before\nrunning `fun` and sets it back to its previous value afterwards. Note that\n`put_locale/2` is used to set the locale, which is thus set only for the\ncurrent process (keep this in mind if you plan on spawning processes inside\n`fun`).\n\nThe value returned by this function is the return value of `fun`.","ref":"Gettext.html#with_locale/3"},{"type":"function","title":"Examples - Gettext.with_locale/3","doc":"Gettext.put_locale(MyApp.Gettext, \"fr\")\n\n    MyApp.Gettext.gettext(\"Hello world\")\n    #=> \"Bonjour monde\"\n\n    Gettext.with_locale(MyApp.Gettext, \"it\", fn ->\n      MyApp.Gettext.gettext(\"Hello world\")\n    end)\n    #=> \"Ciao mondo\"\n\n    MyApp.Gettext.gettext(\"Hello world\")\n    #=> \"Bonjour monde\"","ref":"Gettext.html#with_locale/3-examples"},{"type":"type","title":"Gettext.backend/0","doc":"","ref":"Gettext.html#t:backend/0"},{"type":"type","title":"Gettext.bindings/0","doc":"","ref":"Gettext.html#t:bindings/0"},{"type":"type","title":"Gettext.locale/0","doc":"","ref":"Gettext.html#t:locale/0"},{"type":"behaviour","title":"Gettext.Backend","doc":"Behaviour that defines the macros that a Gettext backend has to implement.","ref":"Gettext.Backend.html"},{"type":"macrocallback","title":"Gettext.Backend.dgettext/2","doc":"Same as `dgettext(domain, msgid, %{})`.\n\nSee also `Gettext.dgettext/4`.","ref":"Gettext.Backend.html#c:dgettext/2"},{"type":"macrocallback","title":"Gettext.Backend.dgettext/3","doc":"Translates the given `msgid` in the given `domain`.\n\n`bindings` is a map of bindings to support interpolation.\n\nSee also `Gettext.dgettext/4`.","ref":"Gettext.Backend.html#c:dgettext/3"},{"type":"macrocallback","title":"Gettext.Backend.dgettext_noop/2","doc":"Marks the given message for extraction and returns it unchanged.\n\nThis macro can be used to mark a message for extraction when `mix\ngettext.extract` is run. The return value is the given string, so that this\nmacro can be used seamlessly in place of the string to extract.","ref":"Gettext.Backend.html#c:dgettext_noop/2"},{"type":"macrocallback","title":"Examples - Gettext.Backend.dgettext_noop/2","doc":"MyApp.Gettext.dgettext_noop(\"errors\", \"Error found!\")\n    #=> \"Error found!\"","ref":"Gettext.Backend.html#c:dgettext_noop/2-examples"},{"type":"macrocallback","title":"Gettext.Backend.dngettext/4","doc":"Same as `dngettext(domain, msgid, msgid_plural, n, %{})`.\n\nSee also `Gettext.dngettext/6`.","ref":"Gettext.Backend.html#c:dngettext/4"},{"type":"macrocallback","title":"Gettext.Backend.dngettext/5","doc":"Translates the given plural message (`msgid` + `msgid_plural`) in the\ngiven `domain`.\n\n`n` is an integer used to determine how to pluralize the\nmessage. `bindings` is a map of bindings to support interpolation.\n\nSee also `Gettext.dngettext/6`.","ref":"Gettext.Backend.html#c:dngettext/5"},{"type":"macrocallback","title":"Gettext.Backend.dngettext_noop/3","doc":"Marks the given message for extraction and returns\n`{msgid, msgid_plural}`.\n\nThis macro can be used to mark a message for extraction when `mix\ngettext.extract` is run. The return value of this macro is `{msgid,\nmsgid_plural}`.","ref":"Gettext.Backend.html#c:dngettext_noop/3"},{"type":"macrocallback","title":"Examples - Gettext.Backend.dngettext_noop/3","doc":"my_fun = fn {msgid, msgid_plural} ->\n      # do something with msgid and msgid_plural\n    end\n\n    my_fun.(MyApp.Gettext.dngettext_noop(\"errors\", \"One error\", \"%{count} errors\"))","ref":"Gettext.Backend.html#c:dngettext_noop/3-examples"},{"type":"macrocallback","title":"Gettext.Backend.dpgettext/3","doc":"Same as `dpgettext(domain, msgctxt, msgid, %{})`.\n\nSee also `Gettext.dpgettext/5`.","ref":"Gettext.Backend.html#c:dpgettext/3"},{"type":"macrocallback","title":"Gettext.Backend.dpgettext/4","doc":"Translates the given `msgid` with a given context (`msgctxt`) in the given `domain`.\n\n`bindings` is a map of bindings to support interpolation.\n\nSee also `Gettext.dpgettext/5`.","ref":"Gettext.Backend.html#c:dpgettext/4"},{"type":"macrocallback","title":"Gettext.Backend.dpngettext/5","doc":"Same as `dpngettext(domain, msgctxt, msgid, msgid_plural, n, %{})`.\n\nSee also `Gettext.dpngettext/7`.","ref":"Gettext.Backend.html#c:dpngettext/5"},{"type":"macrocallback","title":"Gettext.Backend.dpngettext/6","doc":"Translates the given plural message (`msgid` + `msgid_plural`) with the given context (`msgctxt`)\nin the given `domain`.\n\n`n` is an integer used to determine how to pluralize the\nmessage. `bindings` is a map of bindings to support interpolation.\n\nSee also `Gettext.dpngettext/7`.","ref":"Gettext.Backend.html#c:dpngettext/6"},{"type":"macrocallback","title":"Gettext.Backend.gettext/1","doc":"Same as `gettext(msgid, %{})`.\n\nSee also `Gettext.gettext/3`.","ref":"Gettext.Backend.html#c:gettext/1"},{"type":"macrocallback","title":"Gettext.Backend.gettext/2","doc":"Same as `dgettext(\"default\", msgid, %{})`, but will use a per-backend\nconfigured default domain if provided.\n\nSee also `Gettext.gettext/3`.","ref":"Gettext.Backend.html#c:gettext/2"},{"type":"macrocallback","title":"Gettext.Backend.gettext_comment/1","doc":"Stores an \"extracted comment\" for the next message.\n\nThis macro can be used to add comments (Gettext refers to such\ncomments as *extracted comments*) to the next message that will\nbe extracted. Extracted comments will be prefixed with `#.` in POT\nfiles.\n\nCalling this function multiple times will accumulate the comments;\nwhen another Gettext macro (such as `c:gettext/2`) is called,\nthe comments will be extracted and attached to that message, and\nthey will be flushed so as to start again.\n\nThis macro always returns `:ok`.","ref":"Gettext.Backend.html#c:gettext_comment/1"},{"type":"macrocallback","title":"Examples - Gettext.Backend.gettext_comment/1","doc":"MyApp.Gettext.gettext_comment(\"The next message is awesome\")\n    MyApp.Gettext.gettext_comment(\"Another comment for the next message\")\n    MyApp.Gettext.gettext(\"The awesome message\")","ref":"Gettext.Backend.html#c:gettext_comment/1-examples"},{"type":"macrocallback","title":"Gettext.Backend.gettext_noop/1","doc":"Same as `dgettext_noop(\"default\", msgid)`.","ref":"Gettext.Backend.html#c:gettext_noop/1"},{"type":"callback","title":"Gettext.Backend.handle_missing_bindings/2","doc":"Default handling for missing bindings.\n\nThis function is called when there are missing bindings in a message. It\ntakes a `Gettext.MissingBindingsError` struct and the message with the\nwrong bindings left as is with the `%{}` syntax.\n\nFor example, if something like this is called:\n\n    MyApp.Gettext.gettext(\"Hello %{name}, your favorite color is %{color}\", name: \"Jane\", color: \"blue\")\n\nand our `it/LC_MESSAGES/default.po` looks like this:\n\n    msgid \"Hello %{name}, your favorite color is %{color}\"\n    msgstr \"Ciao %{name}, il tuo colore preferito è %{colour}\" # (typo)\n\nthen Gettext will call:\n\n    MyApp.Gettext.handle_missing_bindings(exception, \"Ciao Jane, il tuo colore preferito è %{colour}\")\n\nwhere `exception` is a struct that looks like this:\n\n    %Gettext.MissingBindingsError{\n      backend: MyApp.Gettext,\n      domain: \"default\",\n      locale: \"it\",\n      msgid: \"Ciao %{name}, il tuo colore preferito è %{colour}\",\n      bindings: [:colour],\n    }\n\nThe return value of the `c:handle_missing_bindings/2` callback is used as the\ntranslated string that the message macros and functions return.\n\nThe default implementation for this function uses `Logger.error/1` to warn\nabout the missing binding and returns the translated message with the\nincomplete bindings.\n\nThis function can be overridden. For example, to raise when there are missing\nbindings:\n\n    def handle_missing_bindings(exception, _incomplete) do\n      raise exception\n    end","ref":"Gettext.Backend.html#c:handle_missing_bindings/2"},{"type":"callback","title":"Gettext.Backend.handle_missing_plural_translation/7","doc":"Default handling for plural messages with a missing message.\n\nSame as `c:handle_missing_translation/5`, but for plural messages.\nIn this case, `n` is the number used for pluralizing the translated string.\n\nEarlier versions of this library provided a callback without msgctxt.\nUsers implementing that callback will still get the same results,\nbut they are encouraged to switch to the new 7-argument version.","ref":"Gettext.Backend.html#c:handle_missing_plural_translation/7"},{"type":"callback","title":"Gettext.Backend.handle_missing_translation/5","doc":"Default handling for messages with a missing message.\n\nWhen a Gettext function/macro is called with a string to translate\ninto a locale but that locale doesn't provide a message for that\nstring, this callback is invoked. `msgid` is the string that Gettext\ntried to translate.\n\nThis function should return `{:ok, translated}` if a message can be\nfetched or constructed for the given string. If you cannot find a\nmessage, it should return `{:default, translated}`, where the\ntranslated string defaults to the interpolated msgid. You can, however,\ncustomize the default to, for example, pick the message from the\ndefault locale. The important is to return `:default` instead of `:ok`\nwhenever the result does not quite match the requested locale.\n\nEarlier versions of this library provided a callback without msgctxt.\nUsers implementing that callback will still get the same results,\nbut they are encouraged to switch to the new 5-argument version.","ref":"Gettext.Backend.html#c:handle_missing_translation/5"},{"type":"macrocallback","title":"Gettext.Backend.ngettext/3","doc":"Same as `ngettext(msgid, msgid_plural, n, %{})`.\n\nSee also `Gettext.ngettext/5`.","ref":"Gettext.Backend.html#c:ngettext/3"},{"type":"macrocallback","title":"Gettext.Backend.ngettext/4","doc":"Same as `dngettext(\"default\", msgid, msgid_plural, n, bindings)`, but will\nuse a per-backend configured default domain if provided.\n\nSee also `Gettext.ngettext/5`.","ref":"Gettext.Backend.html#c:ngettext/4"},{"type":"macrocallback","title":"Gettext.Backend.ngettext_noop/2","doc":"Same as `dngettext_noop(\"default\", msgid, mgsid_plural)`, but will use a\nper-backend configured default domain if provided.","ref":"Gettext.Backend.html#c:ngettext_noop/2"},{"type":"macrocallback","title":"Gettext.Backend.pgettext/2","doc":"Same as `pgettext(msgctxt, msgid, %{})`.\n\nSee also `Gettext.pgettext/4`.","ref":"Gettext.Backend.html#c:pgettext/2"},{"type":"macrocallback","title":"Gettext.Backend.pgettext/3","doc":"Translates the given `msgid` with the given context (`msgctxt`).\n\n`bindings` is a map of bindings to support interpolation.\n\nSee also `Gettext.pgettext/4`.","ref":"Gettext.Backend.html#c:pgettext/3"},{"type":"macrocallback","title":"Gettext.Backend.pngettext/4","doc":"Same as `pngettext(msgctxt, msgid, msgid_plural, n, %{})`.\n\nSee also `Gettext.pngettext/6`.","ref":"Gettext.Backend.html#c:pngettext/4"},{"type":"macrocallback","title":"Gettext.Backend.pngettext/5","doc":"Translates the given plural message (`msgid` + `msgid_plural`) with the given context (`msgctxt`).\n\n`n` is an integer used to determine how to pluralize the\nmessage. `bindings` is a map of bindings to support interpolation.\n\nSee also `Gettext.pngettext/6`.","ref":"Gettext.Backend.html#c:pngettext/5"},{"type":"behaviour","title":"Gettext.Interpolation","doc":"Behaviour to provide Gettext string interpolation.\n\nBy default, Gettext uses `Gettext.Interpolation.Default` as the interpolation module.","ref":"Gettext.Interpolation.html"},{"type":"macrocallback","title":"Gettext.Interpolation.compile_interpolate/3","doc":"Called to perform interpolation *at compile time*.","ref":"Gettext.Interpolation.html#c:compile_interpolate/3"},{"type":"callback","title":"Gettext.Interpolation.message_format/0","doc":"Defines the Gettext message format to be used when extracting.\n\nThe default interpolation module that ships with Gettext uses `\"elixir-format\"`.\n\nSee the [GNU Gettext\ndocumentation](https://www.gnu.org/software/gettext/manual/html_node/PO-Files.html#index-msgstr).","ref":"Gettext.Interpolation.html#c:message_format/0"},{"type":"callback","title":"Gettext.Interpolation.runtime_interpolate/2","doc":"Called to perform interpolation *at runtime*.\n\nIf successful, should return `{:ok, interpolated_string}`. If there\nare missing bindings, should return `{:missing_bindings, partially_interpolated, missing}`\nwhere `partially_interpolated` is a string with the available bindings interpolated.","ref":"Gettext.Interpolation.html#c:runtime_interpolate/2"},{"type":"type","title":"Gettext.Interpolation.bindings/0","doc":"","ref":"Gettext.Interpolation.html#t:bindings/0"},{"type":"type","title":"Gettext.Interpolation.translation_type/0","doc":"","ref":"Gettext.Interpolation.html#t:translation_type/0"},{"type":"module","title":"Gettext.Interpolation.Default","doc":"Default implementation for the `Gettext.Interpolation` behaviour.\n\nReplaces `%{binding_name}` with the string value of the `binding_name` binding.","ref":"Gettext.Interpolation.Default.html"},{"type":"macro","title":"Gettext.Interpolation.Default.compile_interpolate/3","doc":"Compiles a static message to interpolate with dynamic bindings.\n\nImplementation of the `c:Gettext.Interpolation.compile_interpolate/3` macro callback.\n\nTakes a static message and some dynamic bindings. The generated\ncode will return an `{:ok, interpolated_string}` tuple if the interpolation\nis successful. If it encounters a binding in the message that is missing from\n`bindings`, it returns `{:missing_bindings, incomplete_string, missing_bindings}`,\nwhere `incomplete_string` is the string with only the present bindings interpolated\nand `missing_bindings` is a list of atoms representing bindings that are in\n`interpolatable` but not in `bindings`.","ref":"Gettext.Interpolation.Default.html#compile_interpolate/3"},{"type":"function","title":"Gettext.Interpolation.Default.message_format/0","doc":"Implementation of `c:Gettext.Interpolation.message_format/0`.","ref":"Gettext.Interpolation.Default.html#message_format/0"},{"type":"function","title":"Examples - Gettext.Interpolation.Default.message_format/0","doc":"iex> Gettext.Interpolation.Default.message_format()\n    \"elixir-format\"","ref":"Gettext.Interpolation.Default.html#message_format/0-examples"},{"type":"function","title":"Gettext.Interpolation.Default.runtime_interpolate/2","doc":"Interpolate a message or interpolatable with the given bindings.\n\nImplementation of the `c:Gettext.Interpolation.runtime_interpolate/2` callback.\n\nThis function takes a message and some bindings and returns an `{:ok,\ninterpolated_string}` tuple if interpolation is successful. If it encounters\na binding in the message that is missing from `bindings`, it returns\n`{:missing_bindings, incomplete_string, missing_bindings}` where\n`incomplete_string` is the string with only the present bindings interpolated\nand `missing_bindings` is a list of atoms representing bindings that are in\n`interpolatable` but not in `bindings`.","ref":"Gettext.Interpolation.Default.html#runtime_interpolate/2"},{"type":"function","title":"Examples - Gettext.Interpolation.Default.runtime_interpolate/2","doc":"iex> msgid = \"Hello %{name}, you have %{count} unread messages\"\n    iex> good_bindings = %{name: \"José\", count: 3}\n    iex> Gettext.Interpolation.Default.runtime_interpolate(msgid, good_bindings)\n    {:ok, \"Hello José, you have 3 unread messages\"}\n    iex> Gettext.Interpolation.Default.runtime_interpolate(msgid, %{name: \"José\"})\n    {:missing_bindings, \"Hello José, you have %{count} unread messages\", [:count]}\n\n    iex> msgid = \"Hello %{name}, you have %{count} unread messages\"\n    iex> interpolatable = Gettext.Interpolation.Default.to_interpolatable(msgid)\n    iex> good_bindings = %{name: \"José\", count: 3}\n    iex> Gettext.Interpolation.Default.runtime_interpolate(interpolatable, good_bindings)\n    {:ok, \"Hello José, you have 3 unread messages\"}\n    iex> Gettext.Interpolation.Default.runtime_interpolate(interpolatable, %{name: \"José\"})\n    {:missing_bindings, \"Hello José, you have %{count} unread messages\", [:count]}","ref":"Gettext.Interpolation.Default.html#runtime_interpolate/2-examples"},{"type":"type","title":"Gettext.Interpolation.Default.interpolatable/0","doc":"Something that can be interpolated.\n\nIt's either a string (a literal) or an atom (representing a binding name).","ref":"Gettext.Interpolation.Default.html#t:interpolatable/0"},{"type":"behaviour","title":"Gettext.Plural","doc":"Behaviour and default implementation for finding plural forms in given\nlocales.\n\nThis module both defines the `Gettext.Plural` behaviour and provides a default\nimplementation for it.","ref":"Gettext.Plural.html"},{"type":"behaviour","title":"Plural Forms - Gettext.Plural","doc":"> For a given language, there is a grammatical rule on how to change words\n> depending on the number qualifying the word. Different languages can have\n> different rules.\n[[source]](https://udn.realityripple.com/docs/Mozilla/Localization/Localization_and_Plurals)\n\nSuch grammatical rules define a number of **plural forms**. For example,\nEnglish has two plural forms: one for when there is just one element (the\n*singular*) and another one for when there are zero or more than one elements\n(the *plural*). There are languages which only have one plural form and there\nare languages which have more than two.\n\nIn GNU Gettext (and in Gettext for Elixir), plural forms are represented by\nincreasing 0-indexed integers. For example, in English `0` means singular and\n`1` means plural.\n\nThe goal of this module is to determine, given a locale:\n\n  * how many plural forms exist in that locale (`nplurals/1`);\n\n  * to what plural form a given number of elements belongs to in that locale\n    (`plural/2`).","ref":"Gettext.Plural.html#module-plural-forms"},{"type":"behaviour","title":"Default Implementation - Gettext.Plural","doc":"`Gettext.Plural` provides a default implementation of a plural module. Most\ncommon languages used on Earth should be covered by this default implementation. If\ncustom pluralization rules are needed (for example, to add additional\nlanguages) a different plural module can be specified when creating a Gettext\nbackend. For example, pluralization rules for the Elvish language could be\nadded as follows:\n\n    defmodule MyApp.Plural do\n      @behaviour Gettext.Plural\n\n      def nplurals(\"elv\"), do: 3\n\n      def plural(\"elv\", 0), do: 0\n      def plural(\"elv\", 1), do: 1\n      def plural(\"elv\", _), do: 2\n\n      # Fall back to Gettext.Plural\n      defdelegate nplurals(locale), to: Gettext.Plural\n      defdelegate plural(locale, n), to: Gettext.Plural\n    end\n\nThe mathematical expressions used in this module to determine the plural form\nof a given number of elements are taken from [this\npage](http://localization-guide.readthedocs.org/en/latest/l10n/pluralforms.html#f2)\nas well as from [Mozilla's guide on \"Localization and\nplurals\"](https://udn.realityripple.com/docs/Mozilla/Localization/Localization_and_Plurals).","ref":"Gettext.Plural.html#module-default-implementation"},{"type":"behaviour","title":"Changing Implementations - Gettext.Plural","doc":"Once you have defined your custom plural forms module, you can use it\nin two ways. You can set it for all Gettext backends in your\nconfiguration:\n\n    # For example, in config/config.exs\n    config :gettext, :plural_forms, MyApp.Plural\n\nor you can set it for each specific backend when you call `use Gettext`:\n\n    defmodule MyApp.Gettext do\n      use Gettext, otp_app: :my_app, plural_forms: MyApp.Plural\n    end\n\n> #### Compile-time Configuration {: .warning}\n>\n> Set `:plural_forms` in your `config/config.exs` and\n> not in `config/runtime.exs`, as Gettext reads this option when\n> compiling your backends.\n\nTask such as `mix gettext.merge` use the plural\nbackend configured under the `:gettext` application, so in general\nthe global configuration approach is preferred.\n\nSome tasks also allow the number of plural forms to be given\nexplicitly, for example:\n\n    mix gettext.merge priv/gettext --locale=gsw_CH --plural-forms=2","ref":"Gettext.Plural.html#module-changing-implementations"},{"type":"behaviour","title":"Unknown Locales - Gettext.Plural","doc":"Trying to call `Gettext.Plural` functions with unknown locales will result in\na `Gettext.Plural.UnknownLocaleError` exception.","ref":"Gettext.Plural.html#module-unknown-locales"},{"type":"behaviour","title":"Language and Territory - Gettext.Plural","doc":"Often, a locale is composed as a language and territory pair, such as\n`en_US`. The default implementation for `Gettext.Plural` handles `xx_YY` by\nforwarding it to `xx` (except for *just Brazilian Portuguese*, `pt_BR`, which\nis not forwarded to `pt` as pluralization rules differ slightly). We treat the\nunderscore as a separator according to\n[ISO 15897](https://en.wikipedia.org/wiki/ISO/IEC_15897). Sometimes, a dash `-` is\nused as a separator (for example [BCP47](https://en.wikipedia.org/wiki/IETF_language_tag)\nlocales use this as in `en-US`): this is *not forwarded* to `en` in the default\n`Gettext.Plural` (and it will raise an `Gettext.Plural.UnknownLocaleError` exception\nif there are no messages for `en-US`). We recommend defining a custom plural forms\nmodule that replaces `-` with `_` if needed.","ref":"Gettext.Plural.html#module-language-and-territory"},{"type":"behaviour","title":"Examples - Gettext.Plural","doc":"An example of the plural form of a given number of elements in the Polish\nlanguage:\n\n    iex> Gettext.Plural.plural(\"pl\", 1)\n    0\n    iex> Gettext.Plural.plural(\"pl\", 2)\n    1\n    iex> Gettext.Plural.plural(\"pl\", 5)\n    2\n    iex> Gettext.Plural.plural(\"pl\", 112)\n    2\n\nAs expected, `nplurals/1` returns the possible number of plural forms:\n\n    iex> Gettext.Plural.nplurals(\"pl\")\n    3","ref":"Gettext.Plural.html#module-examples"},{"type":"callback","title":"Gettext.Plural.init/1","doc":"Should initialize the context for `c:nplurals/1` and `c:plural/2`.\n\nThis callback should perform all preparations for the provided locale, which\nis part of the pluralization context (see `t:pluralization_context/0`). For\nexample, you can use this callback to parse the `Plural-Forms` header and\ndetermine pluralization rules for the locale.\n\nIf defined, Gettext calls this callback *once* at compile time. If not defined,\nthe returned `plural_info` will be equals to the locale found in\n`pluralization_context`.","ref":"Gettext.Plural.html#c:init/1"},{"type":"callback","title":"Examples - Gettext.Plural.init/1","doc":"defmodule MyApp.Plural do\n      @behaviour Gettext.Plural\n\n      @impl true\n      def init(%{locale: _locale, plural_forms_header: header}) do\n        {nplurals, rule} = parse_plural_forms_header(header)\n\n        # This is what other callbacks can use to determine the plural.\n        {nplurals, rule}\n      end\n\n      @impl true\n      def nplurals({_locale, nplurals, _rule}), do: nplurals\n\n      # ...\n    end","ref":"Gettext.Plural.html#c:init/1-examples"},{"type":"function","title":"Gettext.Plural.nplurals/1","doc":"Default implementation of the `c:nplurals/1` callback.","ref":"Gettext.Plural.html#nplurals/1"},{"type":"callback","title":"Gettext.Plural.nplurals/1","doc":"Should return the number of possible plural forms in the given `locale`.","ref":"Gettext.Plural.html#c:nplurals/1"},{"type":"function","title":"Gettext.Plural.plural/2","doc":"Default implementation of the `c:plural/2` callback.","ref":"Gettext.Plural.html#plural/2"},{"type":"callback","title":"Gettext.Plural.plural/2","doc":"Should return the plural form in the given `locale` for the given `count` of\nelements.","ref":"Gettext.Plural.html#c:plural/2"},{"type":"function","title":"Gettext.Plural.plural_forms_header/1","doc":"","ref":"Gettext.Plural.html#plural_forms_header/1"},{"type":"callback","title":"Gettext.Plural.plural_forms_header/1","doc":"Should return the value of the `Plural-Forms` header for the given `locale`,\nif present.\n\nIf the value of the `Plural-Forms` header is unavailable for any reason, this\nfunction should return `nil`.\n\nThis callback is optional. If it's not defined, the fallback returns:\n\n    \"nplurals={nplurals};\"","ref":"Gettext.Plural.html#c:plural_forms_header/1"},{"type":"type","title":"Gettext.Plural.locale/0","doc":"A locale passed to `c:plural/2`.","ref":"Gettext.Plural.html#t:locale/0"},{"type":"type","title":"Gettext.Plural.plural_info/0","doc":"The term that the optional `c:init/1` callback returns.","ref":"Gettext.Plural.html#t:plural_info/0"},{"type":"type","title":"Gettext.Plural.pluralization_context/0","doc":"The context passed to the optional `c:init/1` callback.\n\nIf `:plural_forms_header` is present, it contains the contents\nof the `Plural-Forms` Gettext header.","ref":"Gettext.Plural.html#t:pluralization_context/0"},{"type":"task","title":"mix gettext.extract","doc":"Extracts messages by recompiling the Elixir source code.\n\n```bash\nmix gettext.extract [OPTIONS]\n```\n\nmessages are extracted into POT (Portable Object Template) files with a\n`.pot` extension. The location of these files is determined by the `:otp_app`\nand `:priv` options given by Gettext modules when they call `use Gettext`. One\nPOT file is generated for each message domain.\n\nAll automatically-extracted messages are assigned the `elixir-autogen` flag.\nIf a message from the POT is no longer present and has the `elixir-autogen`\nflag, the message is removed.\n\nBefore `v0.19.0`, the `elixir-format` flag was used to detect automatically\nextracted messages. This has been deprecated in `v0.19.0`. When extracting\nwith the newest version, the new `elixir-autogen` flag is added to all\nautomatically extracted messages.\n\nAll messages are assigned a format flag. When using the default\ninterpolation module, that flag is `elixir-format`. With other interpolation\nmodules, the flag name is defined by that implementation (see\n`c:Gettext.Interpolation.message_format/0`).\n\nIf you would like to verify that your POT files are up to date with the\ncurrent state of the codebase, you can provide the `--check-up-to-date`\nflag. This is particularly useful for automated checks and in CI systems.\nThis validation will fail even when the same calls to Gettext\nonly change location in the codebase:\n\n```bash\nmix gettext.extract --check-up-to-date\n```\n\nIt is possible to pass the `--merge` option to perform merging\nfor every Gettext backend updated during merge:\n\n```bash\nmix gettext.extract --merge\n```\n\nAll other options passed to `gettext.extract` are forwarded to the\n`gettext.merge` task (`Mix.Tasks.Gettext.Merge`), which is called internally\nby this task. For example:\n\n```bash\nmix gettext.extract --merge --no-fuzzy\n```","ref":"Mix.Tasks.Gettext.Extract.html"},{"type":"task","title":"mix gettext.merge","doc":"Merges PO/POT files with PO files.\n\nThis task is used when messages in the source code change: when they do,\n`mix gettext.extract` is usually used to extract the new messages to POT\nfiles. At this point, developers or translators can use this task to \"sync\"\nthe newly-updated POT files with the existing locale-specific PO files. All\nthe metadata for each message (like position in the source code, comments,\nand so on) is taken from the newly-updated POT file; the only things taken\nfrom the PO file are the actual translated strings.\n\n#### Fuzzy Matching\n\nMessages in the updated PO/POT file that have an exact match (a\nmessage with the same `msgid`) in the old PO file are merged as described\nabove. When a message in the updated PO/POT files has no match in the old\nPO file, Gettext attemps a **fuzzy match** for that message. For example, imagine\nwe have this POT file:\n\n    msgid \"hello, world!\"\n    msgstr \"\"\n\nand we merge it with this PO file:\n\n    # No exclamation point here in the msgid\n    msgid \"hello, world\"\n    msgstr \"ciao, mondo\"\n\nSince the two messages are similar, Gettext takes the `msgstr` from the\nexisting message over to the new message, which it however\nmarks as *fuzzy*:\n\n    #, fuzzy\n    msgid \"hello, world!\"\n    msgstr \"ciao, mondo\"\n\nGenerally, a `fuzzy` flag calls for review from a translator.\n\nFuzzy matching can be configured (for example, the threshold for message\nsimilarity can be tweaked) or disabled entirely. Look at the\n[\"Options\" section](#module-options).","ref":"Mix.Tasks.Gettext.Merge.html"},{"type":"task","title":"Usage - mix gettext.merge","doc":"```bash\nmix gettext.merge OLD_FILE UPDATED_FILE [OPTIONS]\nmix gettext.merge DIR [OPTIONS]\n```\n\nIf two files are given as arguments, `OLD_FILE` must be a `.po` file and\n`UPDATE_FILE` must be a `.po`/`.pot` file. The first one is the old PO file,\nwhile the second one is the last generated one. They are merged and written\nover the first file. For example:\n\n```bash\nmix gettext.merge priv/gettext/en/LC_MESSAGES/default.po priv/gettext/default.pot\n```\n\nIf only one argument is given, then that argument must be a directory\ncontaining Gettext messages (with `.pot` files at the root level alongside\nlocale directories - this is usually a \"backend\" directory used by a Gettext\nbackend, see `Gettext.Backend`). For example:\n\n```bash\nmix gettext.merge priv/gettext\n```\n\nIf the `--locale LOCALE` option is given, then only the PO files in\n` / /LC_MESSAGES` will be merged with the POT files in `DIR`. If no\noptions are given, then all the PO files for all locales under `DIR` are\nmerged with the POT files in `DIR`.","ref":"Mix.Tasks.Gettext.Merge.html#module-usage"},{"type":"task","title":"Plural Forms - mix gettext.merge","doc":"By default, Gettext will determine the number of plural forms for newly-generated messages\nby checking the value of `nplurals` in the `Plural-Forms` header in the existing `.po` file. If\na `.po` file doesn't already exist and Gettext is creating a new one or if the `Plural-Forms`\nheader is not in the `.po` file, Gettext will use the number of plural forms that\nthe plural module (see `Gettext.Plural`) returns for the locale of the file being created.\nThe content of the `Plural-Forms` header can be forced through the `--plural-forms-header`\noption (see below).","ref":"Mix.Tasks.Gettext.Merge.html#module-plural-forms"},{"type":"task","title":"Options - mix gettext.merge","doc":"* `--locale` - a string representing a locale. If this is provided, then only the PO\n    files in ` / /LC_MESSAGES` will be merged with the POT files in `DIR`. This\n    option can only be given when a single argument is passed to the task\n    (a directory).\n\n  * `--no-fuzzy` - don't perform fuzzy matching when merging files.\n\n  * `--fuzzy-threshold` - a float between `0` and `1` which represents the\n    minimum Jaro distance needed for two messages to be considered a fuzzy\n    match. Overrides the global `:fuzzy_threshold` option (see the docs for\n    `Gettext` for more information on this option).\n\n  * `--plural-forms` - (**deprecated in v0.22.0**) an integer strictly greater than `0`.\n    If this is passed, new messages in the target PO files will have this number of empty\n    plural forms. This is deprecated in favor of passing the `--plural-forms-header`,\n    which contains the whole plural-forms specification. See the \"Plural forms\" section above.\n\n  * `--plural-forms-header` - the content of the `Plural-Forms` header as a string.\n    If this is passed, new messages in the target PO files will use this content\n    to determine the number of plurals. See the [\"Plural Forms\" section](#module-plural-forms).\n\n  * `--on-obsolete` - controls what happens when **obsolete** messages are found.\n    If `mark_as_obsolete`, messages are kept and marked as obsolete.\n    If `delete`, obsolete messages are deleted. Defaults to `delete`.\n\n  * `--store-previous-message-on-fuzzy-match` - controls if the previous\n    messages are recorded on fuzzy matches. Is off by default.","ref":"Mix.Tasks.Gettext.Merge.html#module-options"},{"type":"function","title":"Mix.Tasks.Gettext.Merge.locale_dir/2","doc":"","ref":"Mix.Tasks.Gettext.Merge.html#locale_dir/2"},{"type":"exception","title":"Gettext.Error","doc":"A generic error raised for a variety of possible Gettext-related reasons.","ref":"Gettext.Error.html"},{"type":"type","title":"Gettext.Error.t/0","doc":"","ref":"Gettext.Error.html#t:t/0"},{"type":"exception","title":"Gettext.MissingBindingsError","doc":"An error message raised for missing bindings errors.","ref":"Gettext.MissingBindingsError.html"},{"type":"type","title":"Gettext.MissingBindingsError.t/0","doc":"","ref":"Gettext.MissingBindingsError.html#t:t/0"},{"type":"exception","title":"Gettext.Plural.UnknownLocaleError","doc":"Raised when a pluralized module doesn't know how to handle a locale.","ref":"Gettext.Plural.UnknownLocaleError.html"},{"type":"exception","title":"Examples - Gettext.Plural.UnknownLocaleError","doc":"raise Gettext.Plural.UnknownLocaleError, \"en-US\"","ref":"Gettext.Plural.UnknownLocaleError.html#module-examples"},{"type":"exception","title":"Gettext.PluralFormError","doc":"An generic error for when a plural form is missing for a given locale.","ref":"Gettext.PluralFormError.html"},{"type":"type","title":"Gettext.PluralFormError.t/0","doc":"","ref":"Gettext.PluralFormError.html#t:t/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}